/**
* Creación de trabajos.
*
* Autor: Ángel Martínez de las Heras
*/



/**
 * Configuración de DBMS_SCHEDULER para updateLastSixMonthsAuditCount
 * 
 * Descripción:
 *   Este bloque PL/SQL crea un trabajo programado en Oracle que ejecuta el procedimiento updateLastSixMonthsAuditCount diariamente a medianoche.
 * 
 * Funcionamiento:
 *   1. Crea un trabajo (job) en el programador de Oracle (DBMS_SCHEDULER).
 *   2. Configura el trabajo para ejecutar el bloque PL/SQL que llama al procedimiento updateLastSixMonthsAuditCount.
 *   3. Establece el intervalo de repetición para que el trabajo se ejecute diariamente a medianoche.
 *   4. Habilita el trabajo para que comience a ejecutarse según lo programado.
 * 
 * Uso:
 *   Ejecutar este bloque PL/SQL para crear y configurar el trabajo programado.
 */
BEGIN
    DBMS_SCHEDULER.CREATE_JOB (
        job_name        => 'dailyAuditCountUpdate',
        job_type        => 'PLSQL_BLOCK',
        job_action      => 'DECLARE RSP VARCHAR2(1000); BEGIN updateLastSixMonthsAuditCount(RSP); END;',
        start_date      => SYSTIMESTAMP,
        repeat_interval => 'FREQ=DAILY; BYHOUR=0; BYMINUTE=0; BYSECOND=0',
        enabled         => TRUE
    );
END;
/


/**
* Configuración de DBMS_SCHEDULER para checkAndCreateCurrentYearREYear
* 
* Descripción:
*   Este bloque PL/SQL crea un trabajo programado en Oracle para ejecutar el procedimiento checkAndCreateCurrentYearREYear 
*   en el inicio de cada año nuevo. Su objetivo es verificar y crear, si es necesario, un registro en 'RE_Year' para el año actual.
*
* Funcionamiento:
*   1. Crea un trabajo en Oracle Scheduler (DBMS_SCHEDULER).
*   2. Configura el trabajo para ejecutar el procedimiento checkAndCreateCurrentYearREYear.
*   3. Establece la fecha de inicio para el próximo año nuevo y configura la repetición anual en cada 1 de enero.
*   4. Habilita el trabajo para que se ejecute automáticamente.
* 
* Uso:
*   Ejecutar este bloque PL/SQL para crear y configurar el trabajo programado.
 */
BEGIN
    DBMS_SCHEDULER.CREATE_JOB (
        job_name        => 'CHECK_CREATE_YEARLY_RE_YEAR_JOB',
        job_type        => 'PLSQL_BLOCK',
        job_action      => 'DECLARE RSP VARCHAR2(1000); BEGIN checkAndCreateCurrentYearREYear(RSP); END;',
        start_date      => TRUNC(ADD_MONTHS(SYSDATE, 12), 'YY'),
        repeat_interval => 'FREQ=YEARLY; BYMONTH=1; BYMONTHDAY=1',
        enabled         => TRUE
    );
END;
/



