/**
* Consultas de comprobación.
*
* Autor: Ángel Martínez de las Heras
*/

-- Listado de zonas geográficas
SELECT * FROM GeographicZone;
SELECT * FROM RE_Geographic;

-- Listado de roles
SELECT * FROM ApproverRole;

-- Listado de áreas
SELECT * FROM Area;

-- Listado de aprobadores
SELECT 
    A.name AS ApproverName,
    AR.name AS RoleName,
    A.contact AS contact,
    AR2.name AS AreaName,
    A.isAvailable AS isAvailable,
    S.name AS SubstituteName
FROM Approver A
INNER JOIN ApproverRole AR ON A.approverRoleID = AR.IDRole
INNER JOIN Area AR2 ON A.areaID = AR2.IDArea
LEFT JOIN Approver S ON A.substituteID = S.IDApprover;

-- Listado de aplicaciones
SELECT 
    App.IDApplication,
    App.name AS ApplicationName,
    App.isInProduction,
    App.productionDate,
    App.averageUsersNumber,
    App.technology,
    App.infraestructureType,
    App.criticality,
    GZ.name AS GeographicZoneName,
    TC.name AS TechnicalContactName,
    TC.contact AS TechnicalContactContact,
    BC.name AS BusinessContactName,
    BC.contact AS BusinessContactContact
FROM Application App
INNER JOIN GeographicZone GZ ON App.geographicZoneID = GZ.IDZone
INNER JOIN Approver TC ON App.technicalContact = TC.IDApprover
INNER JOIN Approver BC ON App.businessContact = BC.IDApprover;

-- Listado de aprobadores de una aplicación
SELECT 
    A.name AS ApproverName,
    AR.name AS RoleName,
    A.contact,
    AR2.name AS AreaName,
    A.isAvailable,
    S.name AS SubstituteName
FROM ApplicationApprovers AA
INNER JOIN Approver A ON AA.approverID = A.IDApprover
INNER JOIN ApproverRole AR ON A.approverRoleID = AR.IDRole
INNER JOIN Area AR2 ON A.areaID = AR2.IDArea
LEFT JOIN Approver S ON A.substituteID = S.IDApprover
WHERE AA.applicationID = :ApplicationID;-- Insertar ID

-- Listado de categorías de cambio
SELECT * FROM ChangeCategory;

-- Listado de cambios
SELECT 
    C.IDChange,
    C.description AS ChangeDescription,
    C.requestDate,
    C.status,
    CC.description AS CategoryDescription,
    CC.importance AS CategoryImportance,
    A.IDApplication,
    A.name AS ApplicationName,
    A.criticality AS ApplicationCriticality,
    A.averageUsersNumber
FROM Change C
INNER JOIN ChangeCategory CC ON C.changeCategoryID = CC.IDCategory
INNER JOIN Application A ON C.applicationID = A.IDApplication;

-- Listado de votos y comentario de un cambio
SELECT 
    A.approverID,
    AP.name AS ApproverName,
    AP.contact AS ApproverContact,
    A.vote,
    A.comments
FROM Approval A
INNER JOIN Approver AP ON A.approverID = AP.IDApprover
WHERE A.changeID = :ChangeID; -- Insertar ID del cambio

-- Listado de ejecuciones
SELECT 
    CE.IDExecution,
    CE.executionDate,
    CE.result,
    C.IDChange,
    C.description AS ChangeDescription,
    C.status AS ChangeStatus,
    A.name AS ApplicationName
FROM ChangeExecution CE
INNER JOIN Change C ON CE.changeID = C.IDChange
INNER JOIN Application A ON C.applicationID = A.IDApplication;

-- Listado de ActionPlan
SELECT 
    AP.IDActionPlan,
    AP.description AS ActionPlanDescription,
    AP.isClosed,
    C.IDChange,
    C.description AS ChangeDescription,
    CE.result AS ChangeExecutionResult
FROM ActionPlan AP
INNER JOIN ChangeExecution CE ON AP.changeExecutionID = CE.IDExecution
INNER JOIN Change C ON CE.changeID = C.IDChange;

-- Listado de Actions de un ActionPlan
SELECT 
    IDAction,
    description,
    deliveryDate,
    doneDate
FROM Action
WHERE actionPlanID = :ActionPlanID; -- Insertar ID

-- Listado de auditorías y número de incumplimientos
SELECT 
    PA.IDAudit,
    PA.auditDate,
    PA.observations,
    COUNT(AC.IDComment) AS NumberOfNonCompliances
FROM ProcessAudit PA
LEFT JOIN AuditComment AC ON PA.IDAudit = AC.auditID
GROUP BY PA.IDAudit, PA.auditDate, PA.observations;

-- Listado de incumplimientos de una auditoría
SELECT 
    IDComment,
    nonCompliances,
    observations
FROM AuditComment
WHERE auditID = :AuditID; -- Insertar ID

-- Ver Logs
SELECT * FROM LogProcedure;

-- Ver errores
SELECT *
FROM LogProcedure
WHERE RSP LIKE 'ERROR%'
ORDER BY IDLog DESC;

-- Ver ejecuciones de procedimiento
SELECT *
FROM LogProcedure
WHERE PROCEDURENAME = 'addComment'
ORDER BY IDLog DESC;



-- Número de cambios en proceso de aprobación actualmente
SELECT changesInApproval
FROM RE_Year
WHERE yearData = EXTRACT(YEAR FROM SYSDATE);

-- Número de cambios aprobados con ejecución incorrecta en el último año:
SELECT incorrectExecution
FROM RE_Year
WHERE yearData = EXTRACT(YEAR FROM SYSDATE) - 1;

-- Responsable técnico con más cambios ejecutados correctamente:
SELECT maxCorrectChangesTechnicalManager
FROM RE_Year
WHERE yearData = EXTRACT(YEAR FROM SYSDATE);

-- Porcentaje de acciones cerradas a tiempo en un año específico:
SELECT doneActionsInTimePercentaje
FROM RE_Year
WHERE yearData = :yearData; -- Insertar año

-- Número total de cambios aprobados por la GCAB en el año en curso:
SELECT GCABApprovedChanges
FROM RE_Year
WHERE yearData = EXTRACT(YEAR FROM SYSDATE);

-- Cambios no aprobados y no ejecutados en un año específico:
SELECT notApprovedChanges
FROM RE_Year
WHERE yearData = :yearData; -- Insertar año

-- Porcentaje de cambios replanificados en una región geográfica específica:
SELECT percentajeRescheduledChanges
FROM RE_Geographic
WHERE geographicZone = :geographicZone; -- Insertar zona

-- Número total de incumplimientos detectados en los últimos 6 meses:
SELECT numNonCompliances
FROM RE_LastSixMonths
WHERE lastDate = (SELECT MAX(lastDate) FROM RE_LastSixMonths);

-- Número total de planes de acción abiertos actualmente:
SELECT openActionPlans
FROM RE_Year
WHERE yearData = EXTRACT(YEAR FROM SYSDATE);

-- Responsable técnico con más cambios en curso actualmente:
SELECT maxOpenChangesTechnicalManager
FROM RE_Year
WHERE yearData = EXTRACT(YEAR FROM SYSDATE);

-- Aprobador más veces sustituido por indisponibilidad no planificada:
SELECT mostReplacedApprover
FROM RE_Year
WHERE yearData = EXTRACT(YEAR FROM SYSDATE);



